@@ -138,5 +138,15 @@ pub fn gen_bstr() -> TokenStream {
             type DefaultType = Self;
         }
         pub type BSTR_abi = *mut u16;
+        impl<'a> ::windows::runtime::IntoParam<'a, BSTR> for &str {
+            fn into_param(self) -> ::windows::runtime::Param<'a, BSTR> {
+                ::windows::runtime::Param::Owned(self.into())
+            }
+        }
+        impl<'a> ::windows::runtime::IntoParam<'a, BSTR> for String {
+            fn into_param(self) -> ::windows::runtime::Param<'a, BSTR> {
+                ::windows::runtime::Param::Owned(self.into())
+            }
+        }
     }
 }
