@@ -19,12 +19,7 @@ pub fn gen_function(def: &MethodDef, gen: &Gen) -> TokenStream {
             if gen.relative.starts_with("Windows.") {
                 quote! { #[link(name = "windows")] }
             } else {
-                let link = def
-                    .impl_map()
-                    .expect("Function")
-                    .scope()
-                    .name()
-                    .to_lowercase();
+                let link = def.impl_map().expect("Function").scope().name().to_lowercase();
 
                 quote! { #[link(name = #link)] }
             }
@@ -48,6 +43,7 @@ pub fn gen_function(def: &MethodDef, gen: &Gen) -> TokenStream {
             quote! {
                 #arch
                 #features
+                #[inline]
                 pub unsafe fn #name<#constraints T: ::windows::runtime::Interface>(#params) -> ::windows::runtime::Result<T> {
                     #[cfg(windows)]
                     {
@@ -71,6 +67,7 @@ pub fn gen_function(def: &MethodDef, gen: &Gen) -> TokenStream {
             quote! {
                 #arch
                 #features
+                #[inline]
                 pub unsafe fn #name<#constraints T: ::windows::runtime::Interface>(#params result__: *mut ::std::option::Option<T>) -> ::windows::runtime::Result<()> {
                     #[cfg(windows)]
                     {
@@ -94,6 +91,7 @@ pub fn gen_function(def: &MethodDef, gen: &Gen) -> TokenStream {
             quote! {
                 #arch
                 #features
+                #[inline]
                 pub unsafe fn #name<#constraints>(#params) -> ::windows::runtime::Result<#return_type_tokens> {
                     #[cfg(windows)]
                     {
@@ -116,6 +114,7 @@ pub fn gen_function(def: &MethodDef, gen: &Gen) -> TokenStream {
             quote! {
                 #arch
                 #features
+                #[inline]
                 pub unsafe fn #name<#constraints>(#params) -> ::windows::runtime::Result<()> {
                     #[cfg(windows)]
                     {
@@ -137,6 +136,7 @@ pub fn gen_function(def: &MethodDef, gen: &Gen) -> TokenStream {
             quote! {
                 #arch
                 #features
+                #[inline]
                 pub unsafe fn #name<#constraints>(#params) #abi_return_type {
                     #[cfg(windows)]
                     {
