@@ -5,20 +5,20 @@ pub fn gen_handle() -> TokenStream {
         #[derive(::std::clone::Clone, ::std::marker::Copy, ::std::default::Default, ::std::fmt::Debug, ::std::cmp::PartialEq, ::std::cmp::Eq)]
         #[repr(transparent)]
         pub struct HANDLE(pub isize);
-        unsafe impl ::windows::Handle for HANDLE {
+        unsafe impl ::windows::runtime::Handle for HANDLE {
             fn is_invalid(&self) -> bool {
                 self.0 == 0 || self.0 == -1
             }
 
-            fn ok(self) -> ::windows::Result<Self> {
+            fn ok(self) -> ::windows::runtime::Result<Self> {
                 if self.is_invalid() {
-                    Err(::windows::Error::from_win32())
+                    Err(::windows::runtime::Error::from_win32())
                 } else {
                     Ok(self)
                 }
             }
         }
-        unsafe impl ::windows::Abi for HANDLE {
+        unsafe impl ::windows::runtime::Abi for HANDLE {
             type Abi = Self;
             type DefaultType = Self;
         }
