@@ -18,21 +18,21 @@ pub fn gen_ntstatus() -> TokenStream {
             }
 
             #[inline]
-            pub const fn to_hresult(self) -> ::windows::HRESULT {
-                ::windows::HRESULT(self.0 | 0x1000_0000)
+            pub const fn to_hresult(self) -> ::windows::runtime::HRESULT {
+                ::windows::runtime::HRESULT(self.0 | 0x1000_0000)
             }
 
             #[inline]
-            pub fn ok(self) -> ::windows::Result<()> {
+            pub fn ok(self) -> ::windows::runtime::Result<()> {
                 if self.is_ok() {
                     Ok(())
                 } else {
-                    Err(::windows::Error::fast_error(self.to_hresult()))
+                    Err(::windows::runtime::Error::fast_error(self.to_hresult()))
                 }
             }
         }
 
-        unsafe impl ::windows::Abi for NTSTATUS {
+        unsafe impl ::windows::runtime::Abi for NTSTATUS {
             type Abi = Self;
             type DefaultType = Self;
         }
