@@ -15,27 +15,27 @@ pub fn gen_pstr() -> TokenStream {
                 Self(::std::ptr::null_mut())
             }
         }
-        unsafe impl ::windows::Abi for PSTR {
+        unsafe impl ::windows::runtime::Abi for PSTR {
             type Abi = Self;
             type DefaultType = Self;
 
-            unsafe fn drop_param(param: &mut ::windows::Param<'_, Self>) {
-                if let ::windows::Param::Boxed(value) = param {
+            unsafe fn drop_param(param: &mut ::windows::runtime::Param<'_, Self>) {
+                if let ::windows::runtime::Param::Boxed(value) = param {
                     if !value.is_null() {
                         unsafe { ::std::boxed::Box::from_raw(value.0); }
                     }
                 }
             }
         }
-        impl<'a> ::windows::IntoParam<'a, PSTR> for &str {
-            fn into_param(self) -> ::windows::Param<'a, PSTR> {
-                ::windows::Param::Boxed(PSTR(::std::boxed::Box::<[u8]>::into_raw(self.bytes().chain(::std::iter::once(0)).collect::<std::vec::Vec<u8>>().into_boxed_slice()) as _))
+        impl<'a> ::windows::runtime::IntoParam<'a, PSTR> for &str {
+            fn into_param(self) -> ::windows::runtime::Param<'a, PSTR> {
+                ::windows::runtime::Param::Boxed(PSTR(::std::boxed::Box::<[u8]>::into_raw(self.bytes().chain(::std::iter::once(0)).collect::<std::vec::Vec<u8>>().into_boxed_slice()) as _))
             }
         }
-        impl<'a> ::windows::IntoParam<'a, PSTR> for String {
-            fn into_param(self) -> ::windows::Param<'a, PSTR> {
+        impl<'a> ::windows::runtime::IntoParam<'a, PSTR> for String {
+            fn into_param(self) -> ::windows::runtime::Param<'a, PSTR> {
                 // TODO: call variant above
-                ::windows::Param::Boxed(PSTR(::std::boxed::Box::<[u8]>::into_raw(self.bytes().chain(::std::iter::once(0)).collect::<std::vec::Vec<u8>>().into_boxed_slice()) as _))
+                ::windows::runtime::Param::Boxed(PSTR(::std::boxed::Box::<[u8]>::into_raw(self.bytes().chain(::std::iter::once(0)).collect::<std::vec::Vec<u8>>().into_boxed_slice()) as _))
             }
         }
     }
